``replication`` - Handling Updates of OSM Data
----------------------------------------------

Replication servers provide regular updates of OSM data. This module
provides helper functions to access the servers and download and
apply updates.

Replication Server Class
^^^^^^^^^^^^^^^^^^^^^^^^

.. autoclass:: osmium.replication.server.ReplicationServer
    :members:
    :undoc-members:

